Coverage report

# Coverage report: 44%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1647 | 925 | 0 | 44%
/home/ken/.local/lib/python3.6/site-packages/avendesora/__init__.py | 13 | 2 | 0 | 85%
/home/ken/.local/lib/python3.6/site-packages/avendesora/account.py | 337 | 191 | 0 | 43%
/home/ken/.local/lib/python3.6/site-packages/avendesora/browsers.py | 27 | 19 | 0 | 30%
/home/ken/.local/lib/python3.6/site-packages/avendesora/charsets.py | 16 | 2 | 0 | 88%
/home/ken/.local/lib/python3.6/site-packages/avendesora/collection.py | 27 | 11 | 0 | 59%
/home/ken/.local/lib/python3.6/site-packages/avendesora/config.py | 76 | 15 | 0 | 80%
/home/ken/.local/lib/python3.6/site-packages/avendesora/dialog.py | 79 | 61 | 0 | 23%
/home/ken/.local/lib/python3.6/site-packages/avendesora/dictionary.py | 18 | 3 | 0 | 83%
/home/ken/.local/lib/python3.6/site-packages/avendesora/generator.py | 116 | 74 | 0 | 36%
/home/ken/.local/lib/python3.6/site-packages/avendesora/gpg.py | 145 | 77 | 0 | 47%
/home/ken/.local/lib/python3.6/site-packages/avendesora/obscure.py | 175 | 105 | 0 | 40%
/home/ken/.local/lib/python3.6/site-packages/avendesora/preferences.py | 14 | 0 | 0 | 100%
/home/ken/.local/lib/python3.6/site-packages/avendesora/recognize.py | 210 | 154 | 0 | 27%
/home/ken/.local/lib/python3.6/site-packages/avendesora/secrets.py | 257 | 120 | 0 | 53%
/home/ken/.local/lib/python3.6/site-packages/avendesora/title.py | 56 | 36 | 0 | 36%
/home/ken/.local/lib/python3.6/site-packages/avendesora/utilities.py | 81 | 55 | 0 | 32%

No items found using the specified filter.